==> react-molecule-data-counter-1.16.0.tgz: package/lib/index.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import { forwardRef, useEffect, useState } from 'react';
import cx from 'classnames';
import PropTypes from 'prop-types';
import AtomButton, { atomButtonDesigns } from '@s-ui/react-atom-button';
import AtomInput, { inputSizes } from '@s-ui/react-atom-input';
import MoleculeField from '@s-ui/react-molecule-field';
import { ACTIONS, BASE_CLASS, CLASS_INPUT_CONTAINER, moleculeDataCounterSizes, sizeConversor } from './config.js';
import useMouseHold from './useMouseHold.js';
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
var MoleculeDataCounter = /*#__PURE__*/forwardRef(function (_ref, ref) {
  var _ref$addIcon = _ref.addIcon,
      addIcon = _ref$addIcon === void 0 ? '+' : _ref$addIcon,
      charsSize = _ref.charsSize,
      disabled = _ref.disabled,
      errorTextProps = _ref.errorText,
      id = _ref.id,
      _ref$inputDisabled = _ref.inputDisabled,
      inputDisabled = _ref$inputDisabled === void 0 ? false : _ref$inputDisabled,
      _ref$isLoading = _ref.isLoading,
      isLoading = _ref$isLoading === void 0 ? false : _ref$isLoading,
      label = _ref.label,
      _ref$max = _ref.max,
      max = _ref$max === void 0 ? 100 : _ref$max,
      maxValueErrorText = _ref.maxValueErrorText,
      maxValueHelpText = _ref.maxValueHelpText,
      _ref$min = _ref.min,
      min = _ref$min === void 0 ? 0 : _ref$min,
      minValueErrorText = _ref.minValueErrorText,
      minValueHelpText = _ref.minValueHelpText,
      onChange = _ref.onChange,
      _ref$size = _ref.size,
      size = _ref$size === void 0 ? inputSizes.MEDIUM : _ref$size,
      _ref$substractIcon = _ref.substractIcon,
      substractIcon = _ref$substractIcon === void 0 ? '-' : _ref$substractIcon,
      initialValue = _ref.initialValue,
      value = _ref.value;
  var initialStateValue;
  var numMax = Number(max);
  var numMin = Number(min);

  if (value !== undefined) {
    initialStateValue = Number(value);
  } else if (initialValue !== undefined) {
    initialStateValue = Number(initialValue);
  } else {
    initialStateValue = numMin + Math.trunc((numMax - numMin) / 2);
  }

  var _useState = useState(),
      lastAction = _useState[0],
      setLastActions = _useState[1];

  var _useState2 = useState(initialStateValue),
      internalValue = _useState2[0],
      setInternalValue = _useState2[1];

  useEffect(function () {
    if (value !== undefined) {
      setInternalValue(Number(value));
    }
  }, [value]);

  var isMaxValue = function isMaxValue(number) {
    if (number === void 0) {
      number = internalValue;
    }

    return number === numMax;
  };

  var isMinValue = function isMinValue(number) {
    if (number === void 0) {
      number = internalValue;
    }

    return number === numMin;
  };

  var isLowerThanMinValue = function isLowerThanMinValue(number) {
    if (number === void 0) {
      number = internalValue;
    }

    return number < numMin;
  };

  var isHigherThanMaxValue = function isHigherThanMaxValue(number) {
    if (number === void 0) {
      number = internalValue;
    }

    return number > numMax;
  };

  var decrementDisabled = disabled || internalValue <= numMin;
  var incrementDisabled = disabled || internalValue >= numMax;

  var assignDiff = function assignDiff(event, _ref2) {
    var diff = _ref2.diff,
        lastAction = _ref2.lastAction;
    setInternalValue(function (currentValue) {
      typeof onChange === 'function' && onChange(event, {
        value: String(currentValue + diff),
        action: lastAction
      });
      return value === undefined ? currentValue + diff : currentValue;
    });
    lastAction && setLastActions(lastAction);
  };

  var incrementValue = function incrementValue(event) {
    var diff = isHigherThanMaxValue(internalValue + 1) ? 0 : 1;
    var lastAction = ACTIONS.MORE;
    assignDiff(event, {
      diff: diff,
      lastAction: lastAction
    });
  };

  var decrementValue = function decrementValue(event) {
    var diff = isLowerThanMinValue(internalValue - 1) ? 0 : -1;
    var lastAction = ACTIONS.LESS;
    assignDiff(event, {
      diff: diff,
      lastAction: lastAction
    });
  };

  var handleChange = function handleChange(event, _ref3) {
    var value = _ref3.value;
    var newValue = parseInt(value, 10);
    assignDiff(event, {
      diff: isNaN(newValue) ? undefined : 0,
      lastAction: ACTIONS.CHANGE
    });
  };

  var handleKeyDown = function handleKeyDown(event) {
    var key = event.key;
    if (key === 'ArrowUp') incrementValue(event);
    if (key === 'ArrowDown') decrementValue(event);
  };

  var helpText, errorText;

  if (!disabled) {
    if (isMaxValue()) helpText = maxValueHelpText;else if (isMinValue()) helpText = minValueHelpText;else helpText = null;
    if (isLowerThanMinValue()) errorText = minValueErrorText;else if (isHigherThanMaxValue()) errorText = maxValueErrorText;else if (errorTextProps) errorText = errorTextProps;else errorText = null;
  }

  return /*#__PURE__*/_jsx("div", {
    className: BASE_CLASS,
    children: /*#__PURE__*/_jsx(MoleculeField, {
      name: id,
      label: label,
      helpText: helpText,
      errorText: errorText,
      children: /*#__PURE__*/_jsxs("div", {
        className: cx(CLASS_INPUT_CONTAINER, CLASS_INPUT_CONTAINER + "--" + size),
        children: [/*#__PURE__*/_jsx(AtomButton, _extends({
          design: atomButtonDesigns.OUTLINE,
          disabled: decrementDisabled,
          isButton: true,
          isLoading: isLoading && lastAction === ACTIONS.LESS,
          size: sizeConversor[size]
        }, useMouseHold(decrementValue, {
          interval: 100,
          delay: 500,
          disabled: decrementDisabled
        }), {
          children: substractIcon
        })), /*#__PURE__*/_jsx(AtomInput, {
          ref: ref,
          charsSize: charsSize || internalValue.toString().length <= 2 ? 2 : internalValue.toString().length,
          disabled: disabled || inputDisabled,
          id: id,
          isLoading: isLoading && lastAction === ACTIONS.CHANGE,
          onChange: handleChange,
          onKeyDown: handleKeyDown,
          size: size,
          value: internalValue
        }), /*#__PURE__*/_jsx(AtomButton, _extends({
          design: atomButtonDesigns.OUTLINE,
          disabled: incrementDisabled,
          isButton: true,
          isLoading: isLoading && lastAction === ACTIONS.MORE,
          size: sizeConversor[size]
        }, useMouseHold(incrementValue, {
          interval: 100,
          delay: 500,
          disabled: incrementDisabled
        }), {
          children: addIcon
        }))]
      })
    })
  });
});
MoleculeDataCounter.displayName = 'MoleculeDataCounter';
export default MoleculeDataCounter;
export { moleculeDataCounterSizes };

==> react-molecule-data-counter-1.17.0.tgz: package/lib/index.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import { forwardRef, useEffect, useState } from 'react';
import cx from 'classnames';
import PropTypes from 'prop-types';
import AtomButton, { atomButtonDesigns } from '@s-ui/react-atom-button';
import AtomInput, { inputSizes } from '@s-ui/react-atom-input';
import MoleculeField from '@s-ui/react-molecule-field';
import { ACTIONS, BASE_CLASS, CLASS_INPUT_CONTAINER, moleculeDataCounterSizes, sizeConversor } from './config.js';
import useMouseHold from './useMouseHold.js';
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
var MoleculeDataCounter = /*#__PURE__*/forwardRef(function (_ref, ref) {
  var _ref$addIcon = _ref.addIcon,
    addIcon = _ref$addIcon === void 0 ? '+' : _ref$addIcon,
    charsSize = _ref.charsSize,
    disabled = _ref.disabled,
    errorTextProps = _ref.errorText,
    id = _ref.id,
    _ref$inputDisabled = _ref.inputDisabled,
    inputDisabled = _ref$inputDisabled === void 0 ? false : _ref$inputDisabled,
    _ref$isLoading = _ref.isLoading,
    isLoading = _ref$isLoading === void 0 ? false : _ref$isLoading,
    label = _ref.label,
    _ref$max = _ref.max,
    max = _ref$max === void 0 ? 100 : _ref$max,
    maxValueErrorText = _ref.maxValueErrorText,
    maxValueHelpText = _ref.maxValueHelpText,
    _ref$min = _ref.min,
    min = _ref$min === void 0 ? 0 : _ref$min,
    minValueErrorText = _ref.minValueErrorText,
    minValueHelpText = _ref.minValueHelpText,
    onChange = _ref.onChange,
    _ref$size = _ref.size,
    size = _ref$size === void 0 ? inputSizes.MEDIUM : _ref$size,
    _ref$substractIcon = _ref.substractIcon,
    substractIcon = _ref$substractIcon === void 0 ? '-' : _ref$substractIcon,
    initialValue = _ref.initialValue,
    value = _ref.value;
  var initialStateValue;
  var numMax = Number(max);
  var numMin = Number(min);
  if (value !== undefined) {
    initialStateValue = Number(value);
  } else if (initialValue !== undefined) {
    initialStateValue = Number(initialValue);
  } else {
    initialStateValue = numMin + Math.trunc((numMax - numMin) / 2);
  }
  var _useState = useState(),
    lastAction = _useState[0],
    setLastActions = _useState[1];
  var _useState2 = useState(initialStateValue),
    internalValue = _useState2[0],
    setInternalValue = _useState2[1];
  useEffect(function () {
    if (value !== undefined) {
      setInternalValue(Number(value));
    }
  }, [value]);
  var isMaxValue = function isMaxValue(number) {
    if (number === void 0) {
      number = internalValue;
    }
    return number === numMax;
  };
  var isMinValue = function isMinValue(number) {
    if (number === void 0) {
      number = internalValue;
    }
    return number === numMin;
  };
  var isLowerThanMinValue = function isLowerThanMinValue(number) {
    if (number === void 0) {
      number = internalValue;
    }
    return number < numMin;
  };
  var isHigherThanMaxValue = function isHigherThanMaxValue(number) {
    if (number === void 0) {
      number = internalValue;
    }
    return number > numMax;
  };
  var decrementDisabled = disabled || internalValue <= numMin;
  var incrementDisabled = disabled || internalValue >= numMax;
  var assignDiff = function assignDiff(event, _ref2) {
    var diff = _ref2.diff,
      lastAction = _ref2.lastAction;
    setInternalValue(function (currentValue) {
      typeof onChange === 'function' && onChange(event, {
        value: String(currentValue + diff),
        action: lastAction
      });
      return value === undefined ? currentValue + diff : currentValue;
    });
    lastAction && setLastActions(lastAction);
  };
  var incrementValue = function incrementValue(event) {
    var diff = isHigherThanMaxValue(internalValue + 1) ? 0 : 1;
    var lastAction = ACTIONS.MORE;
    assignDiff(event, {
      diff: diff,
      lastAction: lastAction
    });
  };
  var decrementValue = function decrementValue(event) {
    var diff = isLowerThanMinValue(internalValue - 1) ? 0 : -1;
    var lastAction = ACTIONS.LESS;
    assignDiff(event, {
      diff: diff,
      lastAction: lastAction
    });
  };
  var handleChange = function handleChange(event, _ref3) {
    var value = _ref3.value;
    var parsedIntNewValue = parseInt(value, 10);
    var diffValue = isNaN(parsedIntNewValue) && 0;
    assignDiff(event, {
      diff: diffValue,
      lastAction: ACTIONS.CHANGE
    });
  };
  var handleKeyDown = function handleKeyDown(event) {
    var key = event.key;
    if (key === 'ArrowUp') incrementValue(event);
    if (key === 'ArrowDown') decrementValue(event);
  };
  var helpText, errorText;
  if (!disabled) {
    if (isMaxValue()) helpText = maxValueHelpText;else if (isMinValue()) helpText = minValueHelpText;else helpText = null;
    if (isLowerThanMinValue()) errorText = minValueErrorText;else if (isHigherThanMaxValue()) errorText = maxValueErrorText;else if (errorTextProps) errorText = errorTextProps;else errorText = null;
  }
  return /*#__PURE__*/_jsx("div", {
    className: BASE_CLASS,
    children: /*#__PURE__*/_jsx(MoleculeField, {
      name: id,
      label: label,
      helpText: helpText,
      errorText: errorText,
      children: /*#__PURE__*/_jsxs("div", {
        className: cx(CLASS_INPUT_CONTAINER, CLASS_INPUT_CONTAINER + "--" + size),
        children: [/*#__PURE__*/_jsx(AtomButton, _extends({
          design: atomButtonDesigns.OUTLINE,
          disabled: decrementDisabled,
          isButton: true,
          isLoading: isLoading && lastAction === ACTIONS.LESS,
          size: sizeConversor[size]
        }, useMouseHold(decrementValue, {
          interval: 100,
          delay: 500,
          disabled: decrementDisabled
        }), {
          children: substractIcon
        })), /*#__PURE__*/_jsx(AtomInput, {
          ref: ref,
          charsSize: charsSize || internalValue.toString().length <= 2 ? 2 : internalValue.toString().length,
          disabled: disabled || inputDisabled,
          id: id,
          isLoading: isLoading && lastAction === ACTIONS.CHANGE,
          onChange: handleChange,
          onKeyDown: handleKeyDown,
          size: size,
          value: internalValue
        }), /*#__PURE__*/_jsx(AtomButton, _extends({
          design: atomButtonDesigns.OUTLINE,
          disabled: incrementDisabled,
          isButton: true,
          isLoading: isLoading && lastAction === ACTIONS.MORE,
          size: sizeConversor[size]
        }, useMouseHold(incrementValue, {
          interval: 100,
          delay: 500,
          disabled: incrementDisabled
        }), {
          children: addIcon
        }))]
      })
    })
  });
});
MoleculeDataCounter.displayName = 'MoleculeDataCounter';
export default MoleculeDataCounter;
export { moleculeDataCounterSizes };
